package com.dsic.gj_erp.service.jhgk.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.dsic.gj_erp.bean.jhgk.DmSygdMx;
import com.dsic.gj_erp.bean.jhgk.DmSygdMxLj;
import com.dsic.gj_erp.bean.jhgk.YdjhImport;
import com.dsic.gj_erp.bean.jhgk.excel.JhxfExcel;
import com.dsic.gj_erp.mapper.jhgk.DmSygdMxMapper;
import com.dsic.gj_erp.mapper.jhgk.DmSygdxqMapper;
import com.dsic.gj_erp.service.jhgk.DmSygdMxLjService;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import java.util.stream.Collectors;

@Service
@AllArgsConstructor
public class YdjhImportService extends ServiceImpl<DmSygdMxMapper, DmSygdMx> {

    private final DmSygdxqMapper sygdxqMapper;
    private final DmSygdMxLjService ljService;
    private final IYdjhImportService importService;

    public List<YdjhImport> list(String begin,String end){
        return importService.list(Wrappers.<YdjhImport>lambdaQuery()
                .between(YdjhImport::getFdxq, begin, end).or().between(YdjhImport::getQwbjs, begin, end)
                .orderByAsc(YdjhImport::getImportIndex)
        );
    }

    @Transactional(rollbackFor = Exception.class)
    public void handler(List<JhxfExcel> objList){
        this.executeYdjhImport(objList);

        List<JhxfExcel> qwb = objList.stream()
                .filter(item->!item.getDcPl().contains("-"))//去除T型材
                .filter(item->!item.getDcPl().contains("/"))//去除T型材
                .filter(item->item.getDcFd()!=null)
                .filter(item -> item.getDcPl().contains("Q")).collect(Collectors.toList());
        this.execute(qwb);

        List<JhxfExcel> list = objList.stream()
                .filter(item->!item.getDcPl().contains("-"))//去除T型材
                .filter(item->!item.getDcPl().contains("/"))//去除T型材
                .filter(item->item.getDcFd()!=null)
                .filter(item -> !item.getDcPl().contains("Q")).collect(Collectors.toList());
        this.execute(list);
    }

    @Transactional(rollbackFor = Exception.class)
    public void executeYdjhImport(List<JhxfExcel> objList){
        Map<String,YdjhImport> map=new HashMap<>();
        for (int i=0;i<objList.size();i++){
            JhxfExcel item=objList.get(i);
            YdjhImport jh = new YdjhImport();
            BeanUtil.copyProperties(item, jh);
            jh.setImportIndex(i);
            YdjhImport _jh = map.get(jh.getDcCh() + jh.getDcPl());
            if (_jh!=null){
                if (_jh.getFdxq()!=null&&jh.getFdxq()==null){
                    jh.setFdxq(_jh.getFdxq());
                }
                if (_jh.getFdxq()==null&&jh.getFdxq()!=null){
                    _jh.setFdxq(jh.getFdxq());
                }
                if(_jh.getQwbjs()!=null&&jh.getQwbjs()==null){
                    jh.setQwbjs(_jh.getQwbjs());
                }
                if(_jh.getQwbjs()==null&&jh.getQwbjs()!=null){
                    _jh.setQwbjs(jh.getQwbjs());
                }
            }else {
                map.put(jh.getDcCh() + jh.getDcPl(),jh);
            }

            YdjhImport one = importService.getOne(new QueryWrapper<YdjhImport>()
                    .select("top 1 id")
                    .eq("dc_ch", jh.getDcCh())
                    .eq("dc_pl", jh.getDcPl())
                    .eq("dc_fd", jh.getDcFd())
            );
            if (ObjUtil.isNotEmpty(one)){
                jh.setId(one.getId());
            }
            importService.saveOrUpdate(jh);
        }
    }

    /**
     * 月度计划导入,不使用月度计划只能排产功能前提下使用该功能导入月度计划
     */
    @Transactional(rollbackFor = Exception.class)
    public void execute(List<JhxfExcel> objList) {
        for(JhxfExcel item:objList){
            if (item.getDcPl().contains("Q")){
                item.setDcPl(item.getDcPl().replace("Q",""));
                item.setQwbBs(true);
            }

            try {
                String format = String.format("%03d", Integer.parseInt(item.getDcPl()));
                item.setDcPl(format);
            }catch (Exception ignored){}

            String[] dcfd=item.getDcFd().split("\\.");

            List<DmSygdMx> addList = new ArrayList<>();

            boolean outContinueFlag=false;
            for(String dcFd:dcfd){
                if (!item.isAvailable()) {
                    baseMapper.delete(new QueryWrapper<DmSygdMx>()
                            .eq("dc_ch", item.getDcCh())
                            .eq("dc_pl", item.getDcPl())
                            .eq("dc_fd", dcFd)
                    );
                    addList.add(this.initDefault(item, dcFd));
                    outContinueFlag=true;
                }
            }
            if (outContinueFlag){
                this.saveBatch(addList);
                continue;
            }

            String dcFd=dcfd[0];
            baseMapper.delete(new QueryWrapper<DmSygdMx>()
                    .eq("dc_ch", item.getDcCh())
                    .eq("dc_pl", item.getDcPl())
                    .eq("dc_fd", dcFd)
            );
            ljService.remove(new QueryWrapper<DmSygdMxLj>()
                    .eq("dcch", item.getDcCh())
                    .eq("pl", item.getDcPl())
                    .eq("fd", dcFd)
            );

            List<DmSygdMxLj> ljList = sygdxqMapper.getSygdLjMx1(item.getDcCh(), item.getDcPl());

            List<DmSygdMx> sygdMxes;
            if (item.getQwbBs()) {
                sygdMxes = this.initBySl(item, ljList.stream().filter(it -> "3".equals(it.getTzbh().substring(5, 6)))
                        .collect(Collectors.toList()), dcFd
                );
            } else {
                sygdMxes = this.initBySl(item, ljList.stream().filter(it -> !"3".equals(it.getTzbh().substring(5, 6)))
                        .collect(Collectors.toList()), dcFd
                );
            }

            addList.addAll(sygdMxes);

            if (item.getPkqgjs() != null) {
                List<DmSygdMx> _sygdMxes = sygdMxes.stream().filter(it -> "7".equals(it.getKw())).collect(Collectors.toList());
                if (!_sygdMxes.isEmpty()) {
                    for (DmSygdMx sygdMx : _sygdMxes) {
                        this.updateByYklm(item, sygdMx);
                    }
                } else {
                    List<DmSygdMxLj> _ljlist = ljList.stream().filter(it -> "7".equals(it.getKw())).collect(Collectors.toList());
                    List<DmSygdMx> list = this.initByYklm(item, _ljlist, dcFd);
                    addList.addAll(list);
                }

                List<DmSygdMx> _sygdMxes1 = sygdMxes.stream().filter(it -> "8".equals(it.getKw())).collect(Collectors.toList());
                if (!_sygdMxes1.isEmpty()) {
                    for (DmSygdMx dmSygdMx : _sygdMxes1) {
                        this.updateByYksk(item, dmSygdMx);
                    }
                } else {
                    List<DmSygdMxLj> _ljlist = ljList.stream().filter(it -> "8".equals(it.getKw())).collect(Collectors.toList());
                    if (!_ljlist.isEmpty()){
                        List<DmSygdMx> list = this.initByYksk(item, _ljlist, dcFd);
                        addList.addAll(list);
                    }
                }
            }

            if (item.getLmqgks() != null) {
                List<DmSygdMx> _sygdMxes = sygdMxes.stream().filter(it -> "5".equals(it.getKw())).collect(Collectors.toList());
                if (!_sygdMxes.isEmpty()) {
                    for (DmSygdMx sygdMx : _sygdMxes) {
                        this.updateByEklm(item, sygdMx);
                    }
                } else {
                    List<DmSygdMxLj> _ljlist = ljList.stream().filter(it -> "5".equals(it.getKw())).collect(Collectors.toList());
                    List<DmSygdMx> list = this.initByEklmbs(item, _ljlist, dcFd);
                    addList.addAll(list);
                }
            }

            if (item.getEkskks() != null) {
                List<DmSygdMx> _sygdMxes = sygdMxes.stream().filter(it -> "9".equals(it.getKw())).collect(Collectors.toList());
                if (!_sygdMxes.isEmpty()) {
                    for (DmSygdMx sygdMx : _sygdMxes) {
                        this.updateByEksk(item, sygdMx);
                    }
                } else {
                    List<DmSygdMxLj> _ljlist = ljList.stream().filter(it -> "9".equals(it.getKw())).collect(Collectors.toList());
                    List<DmSygdMx> list = this.initByEksk(item, _ljlist, dcFd);
                    addList.addAll(list);
                }
            }

            if (item.getSkskqgks() != null) {
                List<DmSygdMx> _sygdMxes = sygdMxes.stream().filter(it -> "14".equals(it.getKw())).collect(Collectors.toList());
                if (!_sygdMxes.isEmpty()) {
                    for (DmSygdMx sygdMx : _sygdMxes) {
                        this.updateBySksk(item, sygdMx);
                    }
                } else {
                    List<DmSygdMxLj> _ljlist = ljList.stream().filter(it -> "14".equals(it.getKw())).collect(Collectors.toList());
                    List<DmSygdMx> list = this.initBySksk(item, _ljlist, dcFd);
                    addList.addAll(list);
                }
            }

            if (item.getPtks() != null) {
                List<DmSygdMx> _sygdMxes = sygdMxes.stream().filter(it -> "6".equals(it.getKw())).collect(Collectors.toList());
                if (!_sygdMxes.isEmpty()) {
                    for (DmSygdMx sygdMx : _sygdMxes) {
                        this.updateBySkpt(item, sygdMx);
                    }
                } else {
                    List<DmSygdMxLj> _ljlist = ljList.stream().filter(it -> "6".equals(it.getKw())).collect(Collectors.toList());
                    List<DmSygdMx> list = this.initBySkpt(item, _ljlist, dcFd);
                    addList.addAll(list);
                }
            }

            if (item.getSkqgks() != null) {
                List<DmSygdMx> _sygdMxes = sygdMxes.stream().filter(it -> "15".equals(it.getKw())).collect(Collectors.toList());
                if (!_sygdMxes.isEmpty()) {
                    for (DmSygdMx sygdMx : _sygdMxes) {
                        this.updateBySkbs(item, sygdMx);
                    }
                } else {
                    List<DmSygdMxLj> _ljlist = ljList.stream().filter(it -> "15".equals(it.getKw())).collect(Collectors.toList());
                    List<DmSygdMx> list = this.initBySkbs(item, _ljlist, dcFd);
                    addList.addAll(list);
                }
            }
            this.saveBatch(addList);

            ljList.forEach(lj -> addList.forEach(mx -> {
                if (lj.getDcch().equals(mx.getDcCh())
                        && lj.getPl().equals(mx.getDcPl())
                        && (StrUtil.isBlank(lj.getTzbh()) || lj.getTzbh().equals(mx.getTzbh()))) {
                    lj.setParentId(mx.getId());
                }
            }));
            ljService.saveBatch(ljList);
        }

    }

    private DmSygdMx initDefault(JhxfExcel item,String dcFd){
        DmSygdMx dmSygdMx = new DmSygdMx();
        dmSygdMx.setDcCh(item.getDcCh());
        dmSygdMx.setDcPl(item.getDcPl());
        dmSygdMx.setDcFd(dcFd);
        dmSygdMx.setJssj(item.getFdxq());
        if (item.getQwbBs()){
            dmSygdMx.setQbs("1");
            dmSygdMx.setJssj(item.getQwbjs());
        }
        return dmSygdMx;
    }

    private List<DmSygdMx> initBySl(JhxfExcel item,List<DmSygdMxLj> bomList,String dcFd){
        List<DmSygdMx> addList=new ArrayList<>();

        if (item.getSl()!=null){
            if (bomList.isEmpty()){
                DmSygdMx dmSygdMx = this.initDefault(item,dcFd);
                addList.add(dmSygdMx);
                return addList;
            }
            ArrayList<DmSygdMxLj> list = bomList.stream().collect(
                    Collectors.collectingAndThen(
                            Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(DmSygdMxLj::getUniqueData))), ArrayList::new)
            );
            for (DmSygdMxLj dmSygdMxLj : list) {
                DmSygdMx init = this.initBySl(item, dmSygdMxLj, dcFd);
                if (item.getQwbBs()) {
                    init.setQbs("1");
                    init.setJssj(item.getQwbjs());
                }
                addList.add(init);
            }
        }
        return addList;
    }

    private List<DmSygdMx> initByYklm(JhxfExcel item, List<DmSygdMxLj> bomList, String dcFd){
        List<DmSygdMx> addList=new ArrayList<>();
        if (bomList.isEmpty()){
            DmSygdMx dmSygdMx = this.initDefault(item,dcFd);
            addList.add(dmSygdMx);
            return addList;
        }
        ArrayList<DmSygdMxLj> list = bomList.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(DmSygdMxLj::getUniqueData))), ArrayList::new)
        );
        for (DmSygdMxLj dmSygdMxLj : list) {
            DmSygdMx init = this.initByYklm(item, dmSygdMxLj, dcFd);
            if (item.getQwbBs()) {
                init.setQbs("1");
                init.setJssj(item.getQwbjs());
            }
            addList.add(init);
        }
        return addList;
    }

    private List<DmSygdMx> initByYksk(JhxfExcel item, List<DmSygdMxLj> bomList, String dcFd){
        List<DmSygdMx> addList=new ArrayList<>();
        if (bomList.isEmpty()){
            DmSygdMx dmSygdMx = this.initDefault(item,dcFd);
            addList.add(dmSygdMx);
            return addList;
        }
        ArrayList<DmSygdMxLj> list = bomList.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(DmSygdMxLj::getUniqueData))), ArrayList::new)
        );
        for (DmSygdMxLj dmSygdMxLj : list) {
            DmSygdMx init = this.initByYksk(item, dmSygdMxLj, dcFd);
            if (item.getQwbBs()) {
                init.setQbs("1");
                init.setJssj(item.getQwbjs());
            }
            addList.add(init);
        }
        return addList;
    }

    private List<DmSygdMx> initByEklmbs(JhxfExcel item, List<DmSygdMxLj> bomList, String dcFd){
        List<DmSygdMx> addList=new ArrayList<>();
        if (bomList.isEmpty()){
            DmSygdMx dmSygdMx = this.initDefault(item,dcFd);
            addList.add(dmSygdMx);
            return addList;
        }
        ArrayList<DmSygdMxLj> list = bomList.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(DmSygdMxLj::getUniqueData))), ArrayList::new)
        );
        for (DmSygdMxLj dmSygdMxLj : list) {
            DmSygdMx init = this.initByEklmbs(item, dmSygdMxLj, dcFd);
            if (item.getQwbBs()) {
                init.setQbs("1");
                init.setJssj(item.getQwbjs());
            }
            addList.add(init);
        }
        return addList;
    }

    private List<DmSygdMx> initByEksk(JhxfExcel item, List<DmSygdMxLj> bomList, String dcFd){
        List<DmSygdMx> addList=new ArrayList<>();
        if (bomList.isEmpty()){
            DmSygdMx dmSygdMx = this.initDefault(item,dcFd);
            addList.add(dmSygdMx);
            return addList;
        }
        ArrayList<DmSygdMxLj> list = bomList.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(DmSygdMxLj::getUniqueData))), ArrayList::new)
        );
        for (DmSygdMxLj dmSygdMxLj : list) {
            DmSygdMx init = this.initByEksk(item, dmSygdMxLj, dcFd);
            if (item.getQwbBs()) {
                init.setQbs("1");
                init.setJssj(item.getQwbjs());
            }
            addList.add(init);
        }
        return addList;
    }

    private List<DmSygdMx> initBySksk(JhxfExcel item, List<DmSygdMxLj> bomList, String dcFd){
        List<DmSygdMx> addList=new ArrayList<>();
        if (bomList.isEmpty()){
            DmSygdMx dmSygdMx = this.initDefault(item,dcFd);
            addList.add(dmSygdMx);
            return addList;
        }
        ArrayList<DmSygdMxLj> list = bomList.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(DmSygdMxLj::getUniqueData))), ArrayList::new)
        );
        for (DmSygdMxLj dmSygdMxLj : list) {
            DmSygdMx init = this.initBySksk(item, dmSygdMxLj, dcFd);
            if (item.getQwbBs()) {
                init.setQbs("1");
                init.setJssj(item.getQwbjs());
            }
            addList.add(init);
        }
        return addList;
    }

    private List<DmSygdMx> initBySkpt(JhxfExcel item, List<DmSygdMxLj> bomList, String dcFd){
        List<DmSygdMx> addList=new ArrayList<>();
        if (bomList.isEmpty()){
            DmSygdMx dmSygdMx = this.initDefault(item,dcFd);
            addList.add(dmSygdMx);
            return addList;
        }
        ArrayList<DmSygdMxLj> list = bomList.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(DmSygdMxLj::getUniqueData))), ArrayList::new)
        );
        for (DmSygdMxLj dmSygdMxLj : list) {
            DmSygdMx init = this.initBySkpt(item, dmSygdMxLj, dcFd);
            if (item.getQwbBs()) {
                init.setQbs("1");
                init.setJssj(item.getQwbjs());
            }
            addList.add(init);
        }
        return addList;
    }

    private List<DmSygdMx> initBySkbs(JhxfExcel item, List<DmSygdMxLj> bomList, String dcFd){
        List<DmSygdMx> addList=new ArrayList<>();
        if (bomList.isEmpty()){
            DmSygdMx dmSygdMx = this.initDefault(item,dcFd);
            addList.add(dmSygdMx);
            return addList;
        }
        ArrayList<DmSygdMxLj> list = bomList.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(DmSygdMxLj::getUniqueData))), ArrayList::new)
        );
        for (DmSygdMxLj dmSygdMxLj : list) {
            DmSygdMx init = this.initBySkbs(item, dmSygdMxLj, dcFd);
            if (item.getQwbBs()) {
                init.setQbs("1");
                init.setJssj(item.getQwbjs());
            }
            addList.add(init);
        }
        return addList;
    }

    private void updateByYklm(JhxfExcel item, DmSygdMx dmSygdMx){
        dmSygdMx.setKw("7");
        dmSygdMx.setQgrq(item.getYkpkjs());
    }

    private void updateByYksk(JhxfExcel item, DmSygdMx dmSygdMx){
        dmSygdMx.setKw("8");
        dmSygdMx.setQgrq(item.getYkpkjs());
    }

    private void updateByEklm(JhxfExcel item, DmSygdMx dmSygdMx){
        dmSygdMx.setKw("5");
        dmSygdMx.setQgrq(item.getLmqgks());
    }

    private void updateByEksk(JhxfExcel item, DmSygdMx dmSygdMx){
        dmSygdMx.setKw("9");
        dmSygdMx.setQgrq(item.getEkskks());
    }

    private void updateBySksk(JhxfExcel item, DmSygdMx dmSygdMx){
        dmSygdMx.setKw("14");
        dmSygdMx.setQgrq(item.getSkskqgks());
        dmSygdMx.setQgjs(item.getSkpkjs());
        dmSygdMx.setQjgrq(item.getQptjs());
    }

    private void updateBySkpt(JhxfExcel item, DmSygdMx dmSygdMx){
        dmSygdMx.setKw("6");
        dmSygdMx.setQgrq(item.getPtks());
    }

    private void updateBySkbs(JhxfExcel item, DmSygdMx dmSygdMx){
        dmSygdMx.setKw("15");
        dmSygdMx.setQgrq(item.getPkqgjs());
    }

    private DmSygdMx initBySl(JhxfExcel item, DmSygdMxLj bom,String dcFd){
        DmSygdMx dmSygdMx = DmSygdMx.ofWithDmSygdMxlj(bom);
        dmSygdMx.setDcFd(dcFd);
        dmSygdMx.setSlrq(item.getSl());
        dmSygdMx.setXcpw(item.getXcpw());
        dmSygdMx.setPwrq(item.getPw());
        return dmSygdMx;
    }

    private DmSygdMx initByYklm(JhxfExcel item, DmSygdMxLj bom,String dcFd){
        DmSygdMx dmSygdMx = DmSygdMx.ofWithDmSygdMxlj(bom);
        dmSygdMx.setDcFd(dcFd);
        dmSygdMx.setSlrq(item.getSl());
        dmSygdMx.setXcpw(item.getXcpw());
        dmSygdMx.setPwrq(item.getPw());
        this.updateByYklm(item,dmSygdMx);
        return dmSygdMx;
    }

    private DmSygdMx initByYksk(JhxfExcel item, DmSygdMxLj bom,String dcFd){
        DmSygdMx dmSygdMx = DmSygdMx.ofWithDmSygdMxlj(bom);
        dmSygdMx.setDcFd(dcFd);
        dmSygdMx.setSlrq(item.getSl());
        dmSygdMx.setXcpw(item.getXcpw());
        dmSygdMx.setPwrq(item.getPw());
        this.updateByYksk(item,dmSygdMx);
        return dmSygdMx;
    }

    private DmSygdMx initByEklmbs(JhxfExcel item, DmSygdMxLj bom,String dcFd){
        DmSygdMx dmSygdMx = DmSygdMx.ofWithDmSygdMxlj(bom);
        dmSygdMx.setDcFd(dcFd);
        dmSygdMx.setSlrq(item.getSl());
        dmSygdMx.setXcpw(item.getXcpw());
        dmSygdMx.setPwrq(item.getPw());
        this.updateByEklm(item,dmSygdMx);
        return dmSygdMx;
    }

    private DmSygdMx initByEksk(JhxfExcel item, DmSygdMxLj bom,String dcFd){
        DmSygdMx dmSygdMx = DmSygdMx.ofWithDmSygdMxlj(bom);
        dmSygdMx.setDcFd(dcFd);
        dmSygdMx.setSlrq(item.getSl());
        dmSygdMx.setXcpw(item.getXcpw());
        dmSygdMx.setPwrq(item.getPw());
        this.updateByEksk(item,dmSygdMx);
        return dmSygdMx;
    }

    private DmSygdMx initBySksk(JhxfExcel item, DmSygdMxLj bom,String dcFd){
        DmSygdMx dmSygdMx = DmSygdMx.ofWithDmSygdMxlj(bom);
        dmSygdMx.setDcFd(dcFd);
        dmSygdMx.setSlrq(item.getSl());
        dmSygdMx.setXcpw(item.getXcpw());
        dmSygdMx.setPwrq(item.getPw());
        this.updateBySksk(item,dmSygdMx);
        return dmSygdMx;
    }

    private DmSygdMx initBySkpt(JhxfExcel item, DmSygdMxLj bom,String dcFd){
        DmSygdMx dmSygdMx = DmSygdMx.ofWithDmSygdMxlj(bom);
        dmSygdMx.setDcFd(dcFd);
        dmSygdMx.setSlrq(item.getSl());
        dmSygdMx.setXcpw(item.getXcpw());
        dmSygdMx.setPwrq(item.getPw());
        this.updateBySkpt(item,dmSygdMx);
        return dmSygdMx;
    }

    private DmSygdMx initBySkbs(JhxfExcel item, DmSygdMxLj bom,String dcFd){
        DmSygdMx dmSygdMx = DmSygdMx.ofWithDmSygdMxlj(bom);
        dmSygdMx.setDcFd(dcFd);
        dmSygdMx.setSlrq(item.getSl());
        dmSygdMx.setXcpw(item.getXcpw());
        dmSygdMx.setPwrq(item.getPw());
        this.updateBySkbs(item,dmSygdMx);
        return dmSygdMx;
    }

}
